.. _external-logging-handlers:

External Logging Handlers
-------------------------

.. currentmodule:: salt.log_handlers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    fluent_mod
    log4mongo_mod
    logstash_mod
    sentry_mod
